@@ -168,11 +168,14 @@ class Realtime():
         for key in all_keys:
             
             #Only keep invests
-            if self.data[key]['invest'] == False: continue
+            try:
+                if self.data[key]['invest'] == False: continue
+            except:
+                continue
             
             #Iterate through all storms
             match = False
-            for key_storm in all_keys:
+            for key_storm in self.data.keys():
                 if self.data[key_storm]['invest'] == True: continue
                 
                 #Check for overlap in lons
@@ -480,9 +483,14 @@ class Realtime():
             
             if ssl_certificate == False and source == 'jtwc':
                 f = urllib.request.urlopen(url,context=ssl._create_unverified_context())
+                content = f.read()
+                content = content.decode("utf-8")
+                content = content.split("\n")
+                content = [(i.replace(" ","")).split(",") for i in content]
+                f.close()
             else:
                 f = urllib.request.urlopen(url)
-            content = read_url(url)
+                content = read_url(url)
 
             #iterate through file lines
             for line in content:
